% Run K-STD (K standardizations of descriptors)
% 
% D ... M-by-N matrix with M descriptors of dimensionality N
% K ... number of clusters
%
%
%   =====================================================================
%   Copyright (C) 2022  Stefan Schubert, stefan.schubert@etit.tu-chemnitz.de
%   
%   This program is free software: you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%   
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
%   
%   You should have received a copy of the GNU General Public License
%   along with this program.  If not, see <http://www.gnu.org/licenses/>.
%   =====================================================================
% 
function D = K_STD(D, K)

  %% clustering with k-means
  options = statset('UseParallel',1);
  idx = kmeans(D, K, 'Distance', 'cosine', 'MaxIter', 1000, 'Replicates', 10, 'Options', options);

  %% standardize each cluster separately
  for idx_k = 1:K
    D(idx==idx_k,:) = STD(D(idx==idx_k,:));
  end

  %% normalize length of all descriptors
  D = normr(D);
end


