% Demo that approximately recreates the results with K-STD from Figure 3
% for Nordland - AlexNet-LSH
%
%
%   =====================================================================
%   Copyright (C) 2022  Stefan Schubert, stefan.schubert@etit.tu-chemnitz.de
%   
%   This program is free software: you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%   
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
%   
%   You should have received a copy of the GNU General Public License
%   along with this program.  If not, see <http://www.gnu.org/licenses/>.
%   =====================================================================
% 
function demo

  %% load data
  data = load('+misc/data_nordland_4seasons_alexnet_lsh.mat');
  
  %% compute the similarity matrices and average precisions 
  % raw descriptors
  S_Raw = -squareform(pdist(data.D, 'cosine'));
  AUC_Raw = misc.getAUC(S_Raw, data.GThard, data.GTsoft, 1);
  
  % standardized descriptors
  S_STD = -squareform(pdist(STD(data.D), 'cosine'));
  AUC_STD = misc.getAUC(S_STD, data.GThard, data.GTsoft, 1);
  
  % K-STD
  ks = round(linspace(2,50,5));

  for i = 1:length(ks)    
    k = ks(i);
    D_kstd = K_STD(data.D, k);
    S_kstd = -squareform(pdist(D_kstd, 'cosine'));
    AUC_kstd(i) = misc.getAUC(S_kstd, data.GThard, data.GTsoft, 1);
  end
  
  %% visualize results
  figure;
  hold all;
  
  plot([0,max(ks)], [AUC_Raw, AUC_Raw]);
  plot([0,max(ks)], [AUC_STD, AUC_STD]);
  plot(ks, AUC_kstd);
  grid on;
  
  legend('Raw', 'STD', 'K-STD', 'location', 'east');
  xlabel('K');
  ylabel('avgP');
  title('Nordland 4 seasons -- AlexNet-LSH');
end